# geopedestrian-py
Determines which locations are reachable by a pedestrian.

![](https://geospatial-ai.de/wp-content/uploads/2024/07/Walking-Areas-Berlin-Olympiastadium.png)

*Walking areas 5, 10, and 15 minutes for a pedestrian starting at the Olympiastadium in Berlin, Germany.*
